import { memo, forwardRef, useRef, useCallback, useImperativeHandle, createElement } from 'react';
import InteractiveEditor from '@liuyunjs/interactive-editor';

const DEFAULT_MATCH = /@\[([^\]]+?)\]\(id:([^\]]+?)\)/gim;
const defaultFormatAtUser = (user) => `@[${user.username}](id:${user.id})`;
const formatMatchedItem = (value) => `@${value}`;
const AtEditor = forwardRef(({ onChange: onChangeCallback, formatAtUser = defaultFormatAtUser, onAt, matchFormattedTextReg = DEFAULT_MATCH, ...restProps }, ref) => {
    const editor = useRef(null);
    const format = useCallback((data) => formatAtUser({ username: data[0], id: data[1] }), [formatAtUser]);
    const onChange = useCallback((data) => {
        onChangeCallback &&
            onChangeCallback({
                displayText: data.displayText,
                text: data.text,
                users: data.data.map(item => ({ username: item[0], id: item[1] })),
            });
    }, [onChangeCallback]);
    useImperativeHandle(ref, function () {
        return {
            focus: editor.current.focus,
            blur: editor.current.blur,
            clear: editor.current.clear,
            trigger: editor.current.trigger,
            addAtUser(user) {
                editor.current.add([user.username, user.id + '']);
            },
        };
    }, []);
    return (createElement(InteractiveEditor, Object.assign({}, restProps, { multiline: true, ref: editor, onChange: onChange, matchFormattedTextReg: matchFormattedTextReg, formatMatchedItem: formatMatchedItem, format: format, trigger: "@", onTrigger: onAt })));
});
var index = memo(AtEditor);

export default index;
//# sourceMappingURL=index.js.map
